@@ -26,7 +26,6 @@
 #include <QListView>
 #include <QTreeView>
 #include <QMouseEvent>
-#include <libfm/fm.h>
 #include "foldermodel.h"
 #include "proxyfoldermodel.h"
 
@@ -121,6 +120,8 @@ public:
 
     void setAutoSelectionDelay(int delay);
 
+    void setShadowHidden(bool shadowHidden);
+
 protected:
     virtual bool event(QEvent* event);
     virtual void contextMenuEvent(QContextMenuEvent* event);
@@ -182,6 +183,7 @@ private:
     QTimer* selChangedTimer_;
     // the cell margins in the icon and thumbnail modes
     QSize itemDelegateMargins_;
+    bool shadowHidden_;
     // smooth scrolling:
     struct scollData {
         int delta;
